@@ -2,7 +2,7 @@ use core::fmt::{self, Debug, Formatter};
 use core::iter::FromIterator;
 
 use super::StaticHeap;
-use crate::iterators::{StaticVecIntoIter, StaticVecIterConst};
+use crate::iterators::{StaticVecIntoIter, StaticVecIterConst, StaticVecIterMut};
 use crate::trait_impls::ExtendEx;
 use crate::StaticVec;
 
@@ -20,6 +20,8 @@ impl<T: Clone, const N: usize> Clone for StaticHeap<T, N> {
   }
 }
 
+// This allows `StaticHeap` to benefit from the optimized
+// "Clone for Copy types" impl that `StaticVec` has.
 impl<T: Copy, const N: usize> Clone for StaticHeap<T, N> {
   #[inline(always)]
   fn clone(&self) -> Self {
@@ -45,7 +47,7 @@ impl<T: Ord, const N: usize> Default for StaticHeap<T, N> {
 impl<T: Debug, const N: usize> Debug for StaticHeap<T, N> {
   #[inline(always)]
   fn fmt(&self, f: &mut Formatter) -> fmt::Result {
-    f.debug_list().entries(self.iter()).finish()
+    f.debug_list().entries(self.data.as_slice()).finish()
   }
 }
 
@@ -199,7 +201,7 @@ impl<T, const N: usize> IntoIterator for StaticHeap<T, N> {
   /// Basic usage:
   /// ```
   /// # use staticvec::*;
-  /// let heap = StaticHeap::from(staticvec![1, 2, 3, 4]);
+  /// let heap = StaticHeap::from([1, 2, 3, 4]);
   /// // Print 1, 2, 3, 4 in arbitrary order
   /// for x in heap.into_iter() {
   ///   // x has type i32, not &i32
@@ -221,3 +223,13 @@ impl<'a, T, const N: usize> IntoIterator for &'a StaticHeap<T, N> {
     self.iter()
   }
 }
+
+impl<'a, T, const N: usize> IntoIterator for &'a mut StaticHeap<T, N> {
+  type Item = &'a mut T;
+  type IntoIter = StaticVecIterMut<'a, T, N>;
+
+  #[inline(always)]
+  fn into_iter(self) -> StaticVecIterMut<'a, T, N> {
+    self.iter_mut()
+  }
+}
